@@ -15,11 +15,14 @@ class ClipContextMenuModel : public muse::uicomponents::AbstractMenuModel
 public:
     ClipContextMenuModel() = default;
 
-    Q_INVOKABLE void loadItems();
+    Q_INVOKABLE void load() override;
+
     ClipKey clipKey() const;
     void setClipKey(const ClipKey& newClipKey);
+
 signals:
     void clipKeyChanged();
+
 private:
     ClipKey m_clipKey;
 };
